
.. _classic_examples_acoustics_1d_heterogeneous:

Acoustics 1D Example 1
------------------------------------------

1D acoustics in a piecewise constant medium to illustrate reflection and
transmission at an interface.

The density and bulk modulus of the medium are specified in setrun.py,
along with a parameter determining what initial conditions to use
(see qinit.f).

Boundary conditions are outflow at both boundaries.

After running this code and creating plots via "make .plots", you
should be able to view the plots in _plots/_PlotIndex.html.

